어베스트 엔드포인트 제품 ( 온프레미스 )

로그인 회원가입 VPS :16020100

업무용 온-프레미스 어베스트 엔드포인트 어베스트 서버용 백신 업무용 월정액 서비스 어베스트 월정액 서비스(PC) 어베스트 월정액 서비스(서버) 포렌식 APT 차단 서비스 어베스트 견적 요청 대표적인 레퍼런스 |
| # 어베스트 엔드포인트 ( 온-프레미스 솔루션 )
|  | Windows PC 및 서버에 보호를 확장할 수 있습니다. 독립형이든 로컬로 관리되는 디바이스든 모두 선택 가능합니다. 사내 단순 네트워크 및 복잡한 네트워크, 또는 폐쇄망 등에 구축형 중앙관리 시스템을 구축할 수 있습니다. 폐쇄망의 경우 중앙관리 서버 만 인터넷에 연결하시면 됩니다. 윈도우 운영체제 XP/ 7/ 8/ 8.1. 10을 지원합니다. 어베스트 엔드포인트 38,700원 부터 어베스트 엔드포인트 플러스 49,600원 부터 어베스트 엔드포인트 스위트 54,200원 부터 어베스트 엔드포인트 스위트 플러스 69,700원 부터 1 년 2 년 3 년
어베스트 온-프레미스 엔드포인트 제품군 가장 신뢰할 수 있는 안티바이러스로 엔드포인트 디바이스를 보호할 수 있으며 중앙에서 모든 것을 쉽게 관리할 수 있습니다. 어베스트 스위트 제품군은 PC와 윈도우 서버 모두를 중앙에서 관리할 수 있으며 중앙관리 소프트웨어를 무상으로 제공하고 있습니다. 고객의 니즈에 따라 선택 가능한 4가지의 엔드포인트 제품
| 엔드포인트 인증 받은 초고속 비즈니스용 안티바이러스로, 원격 관리가 포함된 클라이언트 보호를 제공합니다. 기본 필수 백신 엔진으로 저렴한 백신을 찾는 고객에게 적합합니다.
| 엔드포인트 플러스 최대 엔드포인트로 간단한 네트워크 보안을 지원하며, 원격 관리가 포함된 클라이언트 보호를 제공합니다. 방화벽 및 안티스팸이 포함되어 있습니다.
| 엔드포인트 스위트 통합 패키지 하나로 비즈니스를 완벽하게 보호하며, 원격 관리가 포함된 클라이언트 및 파일 서버 보호를 제공합니다. 기업용 제품 중 가장 많이 찾는 제품입니다.
| 엔드포인트 스위트 플러스 모든 지점을 보호하는 최상의 비즈니스 보안으로, 원격 관리가 포함된 클라이언트 및 파일 서버 보호를 제공합니다. 방화벽 및 안티스팸이 포함되어 있습니다.
|  | 엔드포인트 |  | 엔드포인트 + |  | 엔드포인트 스위트 |  | 엔드포인트 스위트 +
엔드포인트 |  |  |  |  |  |  |  |
지능형 안티바이러스 |  |  |  |  |  |  |  |
데스크톱 방화벽 |  |  |  |  |  |  |  |
안티스팸 |  |  |  |  |  |  |  |
원격 관리 |  |  |  |  |  |  |  |
스몰오피스 관리 |  |  |  |  |  |  |  |
엔터프라이즈 중앙관리 |  |  |  |  |  |  |  |
서버 보호 |  |  |  |  |  |  |  |
파일 서버 |  |  |  |  |  |  |  |
쉐어포인트 |  |  |  |  |  |  |  |
SBS 서버 |  |  |  |  |  |  |  |
익스체인지 서버 |  |  |  |  |  |  |  |
안티스팸 |  |  |  |  |  |  |  |
지원 수량 |  | 5 - 199 |  | 5 - 199 |  | 10 - 20,000 |  | 10 - 20,000
단독버전 다운로드 |  |  |  |  |  |  |  |
중앙관리 콘솔 다운로드 |  |  |  |  |  |  |  |
제품 특징 및 지원 운영체제 라이선스 체계 웹 기반의 중앙관리 스몰오피스 중앙관리 보고서 윈도우 2003 스탠다드 서버에 설치시 반드시 서비스팩2를 먼저 설치하시고 어베스트 설치바랍니다. 클라이언트에서 중앙관리 서버 IP 설정하는 방법

### 월정액

### 개인용

### 업무용

### 고객지원

### 다운로드

### 제품구매

회사소개 사용약관 개인정보취급방침 뉴스수신해지